Federal Work-Study (FWS) Program
Employer Services
Running the MS Word and MS Excel files with Macros
These forms are interactive and require that macros be enabled on your computer. Please save the file(s) locally. You can enable macros by completing the following steps:
For Microsoft Office 2003:
- Open file (it will be either Word or Excel)
- On the Tools menu, point to Macro, and then click Security
- On the Security Level tab, select Medium then press OK
- Exit out of program
- Reopen file
- You will see a Security Warning prompting you to choose whether to enable macros
- Choose the Enable Macros button
- You may now proceed to use the tool
For Microsoft Office 2007:
- Open file (it will be either Word or Excel)
- You will see a Security Warning at the top of the document beneath the toolbar
- Click Options then click Enable this Content
- You may now proceed to use the tool
If you have any questions, please email the FWS program office at fws-admin@umd.edu.